Module aptos_sdk_builder::rust
source · [−]Structs
Functions
Output transaction builders in Rust for the given ABIs.
If local_types is true, we generate a file suitable for the Aptos codebase itself
rather than using serde-generated, standalone definitions.
Walks through the registry replacing variables known to be named as a rust keyword, making the resulting codegen invalid. ie: public function: Identifier => public function_name: Identifier