Function aptos_sdk_builder::rust::replace_keywords
source · [−]pub fn replace_keywords(registry: &mut BTreeMap<String, ContainerFormat>)Expand description
Walks through the registry replacing variables known to be named as a rust keyword, making the resulting codegen invalid. ie: public function: Identifier => public function_name: Identifier